# SPDX-FileCopyrightText: 2024 Alexandru Fikl <alexfikl@gmail.com>
# SPDX-License-Identifier: MIT

from __future__ import annotations

import numpy as np

from pycaputo import fracevolve, fracplot
from pycaputo.fode.gallery import LotkaVolterra3

# setup system (parameters from Figure 5.53 from [Petras2011])
alpha = (0.95, 0.95, 0.95)
y0 = np.array([1.0, 1.4, 1.0])
func = LotkaVolterra3(a=1.0, b=1.0, c=1.0, d=1.0, e=2.0, p=3.0, s=2.7)

print(f"alpha {alpha} y0 {y0} parameters {func}")

# setup controller
from pycaputo.controller import make_fixed_controller

dt = 5.0e-3
control = make_fixed_controller(dt, tstart=0.0, tfinal=200.0)
print(control)

# setup stepper
from pycaputo.fode import caputo

stepper = caputo.PECE(
    derivative_order=alpha,
    control=control,
    source=func.source,
    y0=(y0,),
    corrector_iterations=1,
)

solution = fracevolve(stepper, dtinit=dt)
fracplot(solution, "gallery-lotka-volterra3")
