# SPDX-FileCopyrightText: 2024 Alexandru Fikl <alexfikl@gmail.com>
# SPDX-License-Identifier: MIT

from __future__ import annotations

import numpy as np

from pycaputo import fracevolve, fracplot
from pycaputo.fode.gallery import Volta

# setup system (parameters from Figure 5.62 from [Petras2011])
alpha = (0.98, 0.98, 0.98)
y0 = np.array([8.0, 2.0, 1.0])
func = Volta(a=19.0, b=11.0, c=0.73)

print(f"alpha {alpha} y0 {y0} parameters {func}")

# setup controller
from pycaputo.controller import make_fixed_controller

dt = 5.0e-4
control = make_fixed_controller(dt, tstart=0.0, tfinal=20.0)
print(control)

# setup stepper
from pycaputo.fode import caputo

stepper = caputo.PECE(
    derivative_order=alpha,
    control=control,
    source=func.source,
    y0=(y0,),
    corrector_iterations=1,
)

solution = fracevolve(stepper, dtinit=dt)
fracplot(solution, "gallery-volta")
